
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef speett_MSG_LIB_H
#define speett_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "speettType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  SPEETT_MBOX_NAME                  genomInstanceName("speett")

#define  SPEETT_MAX_RQST_SIZE              1024

#define  SPEETT_MBOX_RQST_SIZE       \
 (BUF_SIZE(SPEETT_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  SPEETT_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  SPEETT_MAX_REPLY_SIZE             1024

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  SPEETT_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(SPEETT_MAX_REPLY_SIZE) \
   + BUF_SIZE(SPEETT_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define SPEETT_INIT_RQST 0
#define SPEETT_LISTEN_RQST 1
#define SPEETT_STOPLISTEN_RQST 2
#define SPEETT_POP_RQST 3
#define SPEETT_PUSH_RQST 4
#define SPEETT_FLUSH_RQST 5
#define SPEETT_ABORT_RQST 6


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS speettClientInit (CLIENT_ID *pClientId);

STATUS speettClientEnd (CLIENT_ID clientId);

int speettAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int speettAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int speettAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS speettInitRqstSend (CLIENT_ID clientId, int *pRqstId,
					 spt_init_p *(in_initp),
					 int replyTimeOut);

extern int speettInitReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int speettInitRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					spt_init_p *(in_initp), 
					
					int *activity, int *bilan);

extern int speettInitRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					spt_init_p *(in_initp), 
					
					int *activity,
					int *bilan);




extern STATUS speettListenRqstSend (CLIENT_ID clientId, int *pRqstId,
					 spt_listen_p *(in_listenp),
					 int replyTimeOut);

extern int speettListenReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int speettListenRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					spt_listen_p *(in_listenp), 
					
					int *activity, int *bilan);

extern int speettListenRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					spt_listen_p *(in_listenp), 
					
					int *activity,
					int *bilan);




extern STATUS speettStopListenRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int speettStopListenReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int speettStopListenRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS speettPopRqstSend (CLIENT_ID clientId, int *pRqstId,
					 spt_pop_p *(in_popp),
					 int replyTimeOut);

extern int speettPopReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      spt_pop_o *(out_popo),
				      int *activity, int *bilan);


extern int speettPopRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					spt_pop_p *(in_popp), 
					spt_pop_o *(out_popo),
					int *activity, int *bilan);

extern int speettPopRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					spt_pop_p *(in_popp), 
					spt_pop_o *(out_popo),
					int *activity,
					int *bilan);




extern STATUS speettPushRqstSend (CLIENT_ID clientId, int *pRqstId,
					 spt_pop_o *(in_pushp),
					 int replyTimeOut);

extern int speettPushReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int speettPushRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					spt_pop_o *(in_pushp), 
					
					int *activity, int *bilan);

extern int speettPushRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					spt_pop_o *(in_pushp), 
					
					int *activity,
					int *bilan);




extern STATUS speettFlushRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int speettFlushReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int speettFlushRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* speett_MSG_LIB_H */

